define(
//begin v1.x content
({
	"saveLabel": "حفظ",
	"saveSettingLabelOn": "تحديد الفترة الزمنية للحفظ الآلي...",
	"saveSettingLabelOff": "ايقاف الحفظ الآلي",
	"saveSettingdialogTitle": "حفظ آلي",
	"saveSettingdialogDescription": "تحديد الفترة الزمنية للحفظ الآلي",
	"saveSettingdialogParamName": "الفترة الزمنية للحفظ الآلي",
	"saveSettingdialogParamLabel": "دقيقة",
	"saveSettingdialogButtonOk": "تحديد الفترة الزمنية",
	"saveSettingdialogButtonCancel": "الغاء",
	"saveMessageSuccess": "تم الحفظ في ${0}",
	"saveMessageFail": "فشل في الحفظ في ${0}"
})

//end v1.x content
);
